import setuptools

setuptools.setup(
    name='pylinklist',  # 包名
    version='0.3',  # 版本
    author='YMZ',  # 你的用户名
    author_email='935460098@qq.com',
    # description='你的第三方库的简介',
    long_description_content_type="""text/markdown""",
    # url='你的网站',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)
# 加注释的地方可以自己解除
